@@ -1,3 +1,5 @@
+// +build integration
+
 package commands_test
 
 import (
@@ -19,6 +21,7 @@ import (
 
 	"gitlab.com/gitlab-org/gitlab-runner/commands"
 	"gitlab.com/gitlab-org/gitlab-runner/common"
+	_ "gitlab.com/gitlab-org/gitlab-runner/executors/docker"
 	_ "gitlab.com/gitlab-org/gitlab-runner/executors/docker/machine"
 	_ "gitlab.com/gitlab-org/gitlab-runner/executors/kubernetes"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/ssh"
@@ -146,8 +149,10 @@ func testRegisterCommandRun(
 		"--config", configFile.Name(),
 		"--url", "http://gitlab.example.com/",
 		"--registration-token", "test-registration-token",
-		"--executor", "shell",
 	}, args...)
+	if !contains(args, "--executor") {
+		args = append(args, "--executor", "shell")
+	}
 
 	comandErr := app.Run(args)
 
@@ -159,6 +164,15 @@ func testRegisterCommandRun(
 	return string(fileContent), "", err
 }
 
+func contains(args []string, s string) bool {
+	for _, arg := range args {
+		if arg == s {
+			return true
+		}
+	}
+	return false
+}
+
 func testAskRunnerOverrideDefaultsForExecutor(t *testing.T, executor string) {
 	basicValidation := func(s *commands.RegisterCommand) {
 		assertExecutorDefaultValues(t, executor, s)
@@ -339,7 +353,7 @@ func assertExecutorDefaultValues(t *testing.T, executor string, s *commands.Regi
 		assert.Equal(t, "busybox:latest", s.RunnerSettings.Docker.Image)
 	case "docker-windows":
 		require.NotNil(t, s.RunnerSettings.Docker)
-		assert.Equal(t, "mcr.microsoft.com/windows/servercore:1809", s.RunnerSettings.Docker.Image)
+		assert.Equal(t, "mcr.microsoft.com/windows/servercore:YYH1", s.RunnerSettings.Docker.Image)
 	case "docker+machine":
 		assert.NotNil(t, s.RunnerSettings.Machine)
 		require.NotNil(t, s.RunnerSettings.Docker)
@@ -402,7 +416,7 @@ func assertExecutorOverridenValues(t *testing.T, executor string, s *commands.Re
 		assert.Equal(t, "nginx:latest", s.RunnerSettings.Docker.Image)
 	case "docker-windows":
 		require.NotNil(t, s.RunnerSettings.Docker)
-		assert.Equal(t, "mcr.microsoft.com/windows/servercore:1903", s.RunnerSettings.Docker.Image)
+		assert.Equal(t, "mcr.microsoft.com/windows/servercore:YYH2", s.RunnerSettings.Docker.Image)
 	case "docker+machine":
 		assert.NotNil(t, s.RunnerSettings.Machine)
 		require.NotNil(t, s.RunnerSettings.Docker)
@@ -451,7 +465,7 @@ func executorAnswers(t *testing.T, executor string) []string {
 		"custom":             {executor},
 		"shell":              {executor},
 		"docker":             {executor, "busybox:latest"},
-		"docker-windows":     {executor, "mcr.microsoft.com/windows/servercore:1809"},
+		"docker-windows":     {executor, "mcr.microsoft.com/windows/servercore:YYH1"},
 		"docker+machine":     {executor, "busybox:latest"},
 		"docker-ssh":         {executor, "busybox:latest", "user", "password", "/home/user/.ssh/id_rsa"},
 		"docker-ssh+machine": {executor, "busybox:latest", "user", "password", "/home/user/.ssh/id_rsa"},
@@ -473,7 +487,7 @@ func executorOverrideAnswers(t *testing.T, executor string) []string {
 		"custom":             {""},
 		"shell":              {""},
 		"docker":             {"nginx:latest"},
-		"docker-windows":     {"mcr.microsoft.com/windows/servercore:1903"},
+		"docker-windows":     {"mcr.microsoft.com/windows/servercore:YYH2"},
 		"docker+machine":     {"nginx:latest"},
 		"docker-ssh":         {"nginx:latest", "root", "admin", "/root/.ssh/id_rsa"},
 		"docker-ssh+machine": {"nginx:latest", "root", "admin", "/root/.ssh/id_rsa"},
@@ -495,7 +509,7 @@ func executorCmdLineArgs(t *testing.T, executor string) []string {
 		"custom":         {"--executor", executor},
 		"shell":          {"--executor", executor},
 		"docker":         {"--executor", executor, "--docker-image", "busybox:latest"},
-		"docker-windows": {"--executor", executor, "--docker-image", "mcr.microsoft.com/windows/servercore:1809"},
+		"docker-windows": {"--executor", executor, "--docker-image", "mcr.microsoft.com/windows/servercore:YYH1"},
 		"docker+machine": {"--executor", executor, "--docker-image", "busybox:latest"},
 		"docker-ssh": {
 			"--executor", executor, "--docker-image", "busybox:latest", "--ssh-user", "user",
@@ -605,30 +619,91 @@ func TestUnregisterOnFailure(t *testing.T) {
 	}
 }
 
-func TestRegisterCommand_FeatureFlag(t *testing.T) {
-	expectedConfig := `
+func TestRegisterCommand(t *testing.T) {
+	type testCase struct {
+		condition      func() bool
+		arguments      []string
+		expectedConfig string
+	}
+
+	testCases := map[string]testCase{
+		"feature flags are included in config": {
+			arguments: []string{
+				"--name", "test-runner",
+				"--feature-flags", "FF_TEST_1:true",
+				"--feature-flags", "FF_TEST_2:false",
+			},
+			expectedConfig: `
   [runners.feature_flags]
     FF_TEST_1 = true
     FF_TEST_2 = false
-`
-
-	network := new(common.MockNetwork)
-	defer network.AssertExpectations(t)
-
-	network.On("RegisterRunner", mock.Anything, mock.Anything).
-		Return(&common.RegisterRunnerResponse{
-			Token: "test-runner-token",
-		}).
-		Once()
-
-	arguments := []string{
-		"--name", "test-runner",
-		"--feature-flags", "FF_TEST_1:true",
-		"--feature-flags", "FF_TEST_2:false",
+`,
+		},
+		"shell defaults to pwsh on Windows with shell executor": {
+			condition: func() bool { return runtime.GOOS == osTypeWindows },
+			arguments: []string{
+				"--name", "test-runner",
+				"--executor", "shell",
+			},
+			expectedConfig: `
+  shell = "pwsh"
+`,
+		},
+		"shell defaults to pwsh on Windows with docker-windows executor": {
+			condition: func() bool { return runtime.GOOS == osTypeWindows },
+			arguments: []string{
+				"--name", "test-runner",
+				"--executor", "docker-windows",
+				"--docker-image", "abc",
+			},
+			expectedConfig: `
+  shell = "pwsh"
+`,
+		},
+		"shell can be overridden to powershell on Windows with shell executor": {
+			condition: func() bool { return runtime.GOOS == osTypeWindows },
+			arguments: []string{
+				"--name", "test-runner",
+				"--executor", "shell",
+				"--shell", "powershell",
+			},
+			expectedConfig: `
+  shell = "powershell"
+`,
+		},
+		"shell can be overridden to powershell on Windows with docker-windows executor": {
+			condition: func() bool { return runtime.GOOS == osTypeWindows },
+			arguments: []string{
+				"--name", "test-runner",
+				"--executor", "docker-windows",
+				"--shell", "powershell",
+				"--docker-image", "abc",
+			},
+			expectedConfig: `
+  shell = "powershell"
+`,
+		},
 	}
 
-	gotConfig, _, err := testRegisterCommandRun(t, network, arguments...)
-	require.NoError(t, err)
+	for tn, tc := range testCases {
+		t.Run(tn, func(t *testing.T) {
+			if tc.condition != nil && !tc.condition() {
+				t.Skip()
+			}
 
-	assert.Contains(t, gotConfig, expectedConfig)
+			network := new(common.MockNetwork)
+			defer network.AssertExpectations(t)
+
+			network.On("RegisterRunner", mock.Anything, mock.Anything).
+				Return(&common.RegisterRunnerResponse{
+					Token: "test-runner-token",
+				}).
+				Once()
+
+			gotConfig, _, err := testRegisterCommandRun(t, network, tc.arguments...)
+			require.NoError(t, err)
+
+			assert.Contains(t, gotConfig, tc.expectedConfig)
+		})
+	}
 }
