@@ -11,7 +11,7 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/trace"
 )
 
-func RunBuildWithMasking(t *testing.T, config *common.RunnerConfig, setup buildSetupFn) {
+func RunBuildWithMasking(t *testing.T, config *common.RunnerConfig, setup BuildSetupFn) {
 	resp, err := common.GetRemoteSuccessfulBuildWithEnvs(config.Shell, false)
 	require.NoError(t, err)
 
@@ -24,6 +24,7 @@ func RunBuildWithMasking(t *testing.T, config *common.RunnerConfig, setup buildS
 		build.Variables,
 		common.JobVariable{Key: "MASKED_KEY", Value: "MASKED_VALUE", Masked: true},
 		common.JobVariable{Key: "CLEARTEXT_KEY", Value: "CLEARTEXT_VALUE", Masked: false},
+		common.JobVariable{Key: "MASKED_KEY_OTHER", Value: "MASKED_VALUE_OTHER", Masked: true},
 	)
 
 	if setup != nil {
@@ -45,6 +46,10 @@ func RunBuildWithMasking(t *testing.T, config *common.RunnerConfig, setup buildS
 	assert.NotContains(t, string(contents), "MASKED_KEY=MASKED_VALUE")
 	assert.Contains(t, string(contents), "MASKED_KEY=[MASKED]")
 
+	assert.NotContains(t, string(contents), "MASKED_KEY_OTHER=MASKED_VALUE_OTHER")
+	assert.NotContains(t, string(contents), "MASKED_KEY_OTHER=[MASKED]_OTHER")
+	assert.Contains(t, string(contents), "MASKED_KEY_OTHER=[MASKED]")
+
 	assert.NotContains(t, string(contents), "CLEARTEXT_KEY=[MASKED]")
 	assert.Contains(t, string(contents), "CLEARTEXT_KEY=CLEARTEXT_VALUE")
 }
