@@ -161,13 +161,11 @@ func (e *executor) loadPrebuiltImage(path, ref, tag string) (*types.ImageInspect
 		Source:     file,
 		SourceName: "-",
 	}
-	options := types.ImageImportOptions{Tag: tag}
-
-	// TODO: Remove check in 14.0 https://gitlab.com/gitlab-org/gitlab-runner/-/issues/26679
-	if e.Build.IsFeatureFlagOn(featureflags.ResetHelperImageEntrypoint) {
+	options := types.ImageImportOptions{
+		Tag: tag,
 		// NOTE: The ENTRYPOINT metadata is not preserved on export, so we need to reapply this metadata on import.
 		// See https://gitlab.com/gitlab-org/gitlab-runner/-/merge_requests/2058#note_388341301
-		options.Changes = append(options.Changes, `ENTRYPOINT ["/usr/bin/dumb-init", "/entrypoint"]`)
+		Changes: []string{`ENTRYPOINT ["/usr/bin/dumb-init", "/entrypoint"]`},
 	}
 
 	if err = e.client.ImageImportBlocking(e.Context, source, ref, options); err != nil {
@@ -222,8 +220,13 @@ func (e *executor) getLocalHelperImage() *types.ImageInspect {
 		return nil
 	}
 
+	var flavor string
+	if e.Config.Docker != nil {
+		flavor = e.Config.Docker.HelperImageFlavor
+	}
+
 	architecture := e.helperImageInfo.Architecture
-	prebuiltFileName := getPrebuiltFileName(architecture, e.Config.Shell)
+	prebuiltFileName := getPrebuiltFileName(architecture, flavor, e.Config.Shell)
 	for _, dockerPrebuiltImagesPath := range PrebuiltImagesPaths {
 		dockerPrebuiltImageFilePath := filepath.Join(dockerPrebuiltImagesPath, prebuiltFileName)
 		image, err := e.loadPrebuiltImage(
@@ -242,12 +245,16 @@ func (e *executor) getLocalHelperImage() *types.ImageInspect {
 	return nil
 }
 
-func getPrebuiltFileName(architecture, shell string) string {
-	if shell == shells.SNPwsh {
-		return fmt.Sprintf("prebuilt-%s-%s%s", architecture, shell, prebuiltImageExtension)
+func getPrebuiltFileName(architecture, flavor string, shell string) string {
+	if flavor == "" {
+		flavor = helperimage.DefaultFlavor
 	}
 
-	return fmt.Sprintf("prebuilt-%s%s", architecture, prebuiltImageExtension)
+	if shell == shells.SNPwsh {
+		return fmt.Sprintf("prebuilt-%s-%s-%s%s", flavor, architecture, shell, prebuiltImageExtension)
+	}
+
+	return fmt.Sprintf("prebuilt-%s-%s%s", flavor, architecture, prebuiltImageExtension)
 }
 
 func (e *executor) getBuildImage() (*types.ImageInspect, error) {
@@ -1027,6 +1034,7 @@ func (e *executor) prepareHelperImage() (helperimage.Info, error) {
 		OperatingSystem: e.info.OperatingSystem,
 		Shell:           e.Config.Shell,
 		GitLabRegistry:  e.Build.IsFeatureFlagOn(featureflags.GitLabRegistryHelperImage),
+		Flavor:          e.Config.Docker.HelperImageFlavor,
 	})
 }
 
