@@ -1,7 +1,10 @@
+// +build integration
+
 package shell_test
 
 import (
 	"bytes"
+	"errors"
 	"fmt"
 	"io/ioutil"
 	"net/http"
@@ -224,7 +227,7 @@ func TestBuildJobStatusEnvVars(t *testing.T) {
 		fail   bool
 		assert func(t *testing.T, err error, build *common.Build, out string)
 	}{
-		"state and stage on failure": {
+		"state on failure": {
 			fail: true,
 			assert: func(t *testing.T, err error, build *common.Build, out string) {
 				assert.Error(t, err)
@@ -232,7 +235,7 @@ func TestBuildJobStatusEnvVars(t *testing.T) {
 				assert.Equal(t, common.BuildRunRuntimeFailed, build.CurrentState())
 			},
 		},
-		"state and stage on success": {
+		"state on success": {
 			fail: false,
 			assert: func(t *testing.T, err error, build *common.Build, out string) {
 				assert.NoError(t, err)
@@ -825,6 +828,87 @@ func TestBuildWithGitSubmoduleStrategyNone(t *testing.T) {
 	}
 }
 
+func TestBuildWithGitSubmodulePaths(t *testing.T) {
+	// Some of these fail on earlier versions of git
+	// We can just skip it since we pass them directly to git and don't care for version support
+	skipOnGit(t, "< 1.9")
+
+	tests := map[string]struct {
+		paths                   string
+		expectedBuildError      error
+		expectedSubmoduleExists bool
+	}{
+		"include submodule": {
+			paths:                   "gitlab-grack",
+			expectedBuildError:      nil,
+			expectedSubmoduleExists: true,
+		},
+		"exclude submodule": {
+			paths:                   ":(exclude)gitlab-grack",
+			expectedBuildError:      nil,
+			expectedSubmoduleExists: false,
+		},
+		"exclude submodule with single space": {
+			paths:                   ":(exclude) gitlab-grack",
+			expectedBuildError:      nil,
+			expectedSubmoduleExists: true,
+		},
+		"exclude submodule with multiple spaces": {
+			paths:                   ":(exclude)  gitlab-grack",
+			expectedBuildError:      nil,
+			expectedSubmoduleExists: true,
+		},
+		"exclude submodule with space between all statements": {
+			paths:                   ": (exclude) gitlab-grack",
+			expectedBuildError:      &exec.ExitError{},
+			expectedSubmoduleExists: false,
+		},
+		"exclude submodule invalid": {
+			paths:                   "::::(exclude) gitlab-grack",
+			expectedBuildError:      &exec.ExitError{},
+			expectedSubmoduleExists: false,
+		},
+		"empty": {
+			paths:                   "    ",
+			expectedBuildError:      nil,
+			expectedSubmoduleExists: true,
+		},
+	}
+
+	for tn, tt := range tests {
+		t.Run(tn, func(t *testing.T) {
+			shellstest.OnEachShell(t, func(t *testing.T, shell string) {
+				successfulBuild, err := common.GetSuccessfulBuild()
+				assert.NoError(t, err)
+
+				build, cleanup := newBuild(t, successfulBuild, shell)
+				defer cleanup()
+
+				build.Variables = append(
+					build.Variables,
+					common.JobVariable{Key: "GIT_SUBMODULE_STRATEGY", Value: "normal"},
+					common.JobVariable{Key: "GIT_SUBMODULE_PATHS", Value: tt.paths},
+				)
+
+				out, err := buildtest.RunBuildReturningOutput(t, build)
+				err = errors.Unwrap(err)
+				require.IsType(t, err, tt.expectedBuildError)
+
+				assert.NotContains(t, out, "Skipping Git submodules setup")
+				assert.Contains(t, out, "Updating/initializing submodules...")
+
+				_, err = os.Stat(filepath.Join(build.BuildDir, "gitlab-grack", ".git"))
+				if tt.expectedSubmoduleExists {
+					require.NoError(t, err, "Submodule should have been initialized")
+					return
+				}
+
+				require.True(t, errors.Is(err, os.ErrNotExist), "Submodule is initialized but shouldn't be")
+			})
+		})
+	}
+}
+
 func TestBuildWithGitSubmoduleStrategyNormal(t *testing.T) {
 	shellstest.OnEachShell(t, func(t *testing.T, shell string) {
 		successfulBuild, err := common.GetSuccessfulBuild()
